@@ -560,6 +560,7 @@ sub textout ($%);
 sub benchmark_enabled ($);
 sub benchmark_enter ($$;$$$);
 sub benchmark_leave ($$;$$);
+sub benchmark_reset ($);
 sub benchmark_start ($;$);
 sub benchmark_stats ($;$);
 sub benchmark_stop ($);
@@ -2065,6 +2066,19 @@ sub benchmark_leave ($$;$$) {
 
 ###############################################################################
 
+=item benchmark_reset()
+
+Clear all benchmarking statistics accumulated so far.
+
+=cut
+
+sub benchmark_reset ($) {
+    my $self=shift;
+    %{$self->_benchmark_hash()}=();
+}
+
+###############################################################################
+
 =item benchmark_start(;$)
 
 Start automatic system-wide page rendering benchmarking.
