@@ -1,4 +1,6 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
+use warnings;
+use strict;
 
 eval "use XAO::TestUtils";
 if($@) { die "Can't find XAO::Base - call as ``perl -Mblib $0'' ($@)\n" }
@@ -7,5 +9,5 @@ if(@ARGV) {
     XAO::TestUtils::xao_test(@ARGV);
 }
 else {
-    XAO::TestUtils::xao_test_all('testcases::Web');
+    XAO::TestUtils::xao_test_all('testcases');
 }
